Immediately update your application's privacy policy to explicitly state if and how information relating to criminal convictions or offences is collected and processed. Clearly detail the specific legal basis that permits this processing, the purposes for collection, how the data is used, stored with the highest level of security, and its retention period. Ensure full compliance with all legal requirements.